==> sakae-opentype-1_0_3.tar.gz: sakae-opentype/src/jp/cssj/sakae/opentype/truetype/GlyfDescript.java <==
/*

 Copyright 2001  The Apache Software Foundation 

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 */
package jp.cssj.sakae.opentype.truetype;

import java.io.IOException;
import java.io.RandomAccessFile;

import jp.cssj.sakae.opentype.table.GlyfTable;
import jp.cssj.sakae.opentype.table.Program;

/**
 * @version $Id: GlyfDescript.java,v 1.2 2007-05-06 04:27:01 miyabe Exp $
 * @author <a href="mailto:david@steadystate.co.uk">David Schweinsberg</a>
 */
public abstract class GlyfDescript extends Program implements GlyphDescription {

	// flags
	public static final byte onCurve = 0x01;

	public static final byte xShortVector = 0x02;

	public static final byte yShortVector = 0x04;

	public static final byte repeat = 0x08;

	public static final byte xDual = 0x10;

	public static final byte yDual = 0x20;

	protected GlyfTable parentTable;

	private int numberOfContours;

	private short xMin;

	private short yMin;

	private short xMax;

	private short yMax;

	protected GlyfDescript(GlyfTable parentTable, int numberOfContours,
			RandomAccessFile raf) throws IOException {
		this.parentTable = parentTable;
		this.numberOfContours = numberOfContours;
		xMin = (short) (raf.read() << 8 | raf.read());
		yMin = (short) (raf.read() << 8 | raf.read());
		xMax = (short) (raf.read() << 8 | raf.read());
		yMax = (short) (raf.read() << 8 | raf.read());
	}

	public int getNumberOfContours() {
		return numberOfContours;
	}

	public short getXMaximum() {
		return xMax;
	}

	public short getXMinimum() {
		return xMin;
	}

	public short getYMaximum() {
		return yMax;
	}

	public short getYMinimum() {
		return yMin;
	}
}

==> sakae-opentype-1_0_4.tar.gz: sakae-opentype/src/jp/cssj/sakae/opentype/truetype/GlyfDescript.java <==
/*

 Copyright 2001  The Apache Software Foundation 

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 */
package jp.cssj.sakae.opentype.truetype;

import java.io.IOException;
import java.io.RandomAccessFile;

import jp.cssj.sakae.opentype.table.GlyfTable;
import jp.cssj.sakae.opentype.table.Program;

/**
 * @version $Id: GlyfDescript.java,v 1.2 2007-05-06 04:27:01 miyabe Exp $
 * @author <a href="mailto:david@steadystate.co.uk">David Schweinsberg</a>
 */
public abstract class GlyfDescript extends Program implements GlyphDescription {

	// flags
	public static final byte onCurve = 0x01;

	public static final byte xShortVector = 0x02;

	public static final byte yShortVector = 0x04;

	public static final byte repeat = 0x08;

	public static final byte xDual = 0x10;

	public static final byte yDual = 0x20;

	protected GlyfTable parentTable;

	private int numberOfContours;

	private short xMin;

	private short yMin;

	private short xMax;

	private short yMax;

	protected GlyfDescript(GlyfTable parentTable, int numberOfContours,
			RandomAccessFile raf) throws IOException {
		this.parentTable = parentTable;
		this.numberOfContours = numberOfContours;
		this.xMin = (short) (raf.read() << 8 | raf.read());
		this.yMin = (short) (raf.read() << 8 | raf.read());
		this.xMax = (short) (raf.read() << 8 | raf.read());
		this.yMax = (short) (raf.read() << 8 | raf.read());
	}

	public int getNumberOfContours() {
		return this.numberOfContours;
	}

	public short getXMaximum() {
		return this.xMax;
	}

	public short getXMinimum() {
		return this.xMin;
	}

	public short getYMaximum() {
		return this.yMax;
	}

	public short getYMinimum() {
		return this.yMin;
	}
}
